==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-leave/translations/lxqt-leave_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translatorcomment>적절한 표현을 모르겠습니다.</translatorcomment>
        <translation type="unfinished">떠나기</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;무엇을 하길 원하십니까?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="55"/>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="73"/>
        <source>Reboot</source>
        <translation>재시작</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="60"/>
        <source>Shutdown</source>
        <translation>시스템 종료</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="65"/>
        <source>Suspend</source>
        <translation>대기</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="70"/>
        <source>Lock screen</source>
        <translation>잠금</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="78"/>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Logout.</source>
        <translation>로그아웃.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Lockscreen.</source>
        <translation>잠금.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Suspend.</source>
        <translation>대기.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Hibernate.</source>
        <translation>최대 절전 모드.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Shutdown.</source>
        <translation>시스템 종료.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Reboot.</source>
        <translation>재시작.</translation>
    </message>
</context>
</TS>

==> lxqt-session-1.0.0.tar.xz: lxqt-session-1.0.0/lxqt-leave/translations/lxqt-leave_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translatorcomment>적절한 표현을 모르겠습니다.</translatorcomment>
        <translation>그만두기</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;무엇을 하길 원하십니까?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="55"/>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="73"/>
        <source>Reboot</source>
        <translation>재시작</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="60"/>
        <source>Shutdown</source>
        <translation>시스템 종료</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="65"/>
        <source>Suspend</source>
        <translation>대기</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="70"/>
        <source>Lock screen</source>
        <translation>잠금</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="78"/>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Logout.</source>
        <translation>로그아웃.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Lockscreen.</source>
        <translation>잠금.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Suspend.</source>
        <translation>대기.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Hibernate.</source>
        <translation>최대 절전 모드.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Shutdown.</source>
        <translation>시스템 종료.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Reboot.</source>
        <translation>재시작.</translation>
    </message>
</context>
</TS>
